OC.L10N.register(
    "dav",
    {
    "Calendar" : "التقويم",
    "Tasks" : "المهام",
    "Personal" : "شخصي",
    "{actor} created calendar {calendar}" : "{actor} قام بإنشاء تقويم {calendar}",
    "You created calendar {calendar}" : "قمت بإنشاء التقويم {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} قام بحذف التقويم {calendar}",
    "You deleted calendar {calendar}" : "لقد قمت بحذف التقويم {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} حدّث التقويم {calendar}",
    "You updated calendar {calendar}" : "لقد قمت بتحديث التقويم {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} استعاد التقويم {calendar}",
    "You restored calendar {calendar}" : "أنت استعدت التقويم {calendar}",
    "You shared calendar {calendar} as public link" : "أنت شاركت التقويم {calendar} كرابطٍ عموميٍ public link",
    "You removed public link for calendar {calendar}" : "أنت ألغيب الرابط العمومي للتقويم {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} قام بمشاركة التقويم {calendar} معك",
    "You shared calendar {calendar} with {user}" : "لقد قمت بمشاركة التقويم {calendar} مع {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} قام بمشاركة التقويم {calendar} مع {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} أزال مشاركة التقويم {calendar} منك",
    "You unshared calendar {calendar} from {user}" : "لقد أزلت مشاركة التقويم {calendar} من {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} أزال مشاركة التقويم {calendar} من {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} أزال مشاركة التقويم {calendar} من نفسه",
    "You shared calendar {calendar} with group {group}" : "أنت شاركت التقويم {calendar} مع المجموعة {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} شارك التقويم {calendar} مع المجموعة {group}",
    "You unshared calendar {calendar} from group {group}" : "أنت أزلت مشاركة التقويم {calendar} من المجموعة {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} أزال مشاركة التقويم {calendar} من المجموعة {group}",
    "Untitled event" : "حدث بدون اسم",
    "{actor} created event {event} in calendar {calendar}" : "{actor} أنشأ الحدث {event} في التقويم {calendar}",
    "You created event {event} in calendar {calendar}" : "أنت أنشأت الحدث {event} في التقويم {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} حذف الحدث {event} من التقويم {calendar}",
    "You deleted event {event} from calendar {calendar}" : "أنت حذفت الحدث {event} من التقويم {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} عدّل الحدث {event} في التقويم {calendar}",
    "You updated event {event} in calendar {calendar}" : "أنت عدّلت الحدث {event} في التقويم {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} نقل الحدث {event} من التقويم {sourceCalendar} إلى التقويم {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "أنت نقلت الحدث {event} من التقويم {sourceCalendar} إلى التقويم {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} قام باستعادة الحدث {event} للتقويم {calendar}",
    "You restored event {event} of calendar {calendar}" : "أنت قمت باستعادة الحدث {event} للتقويم {calendar}",
    "Busy" : "مشغول",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} قائمة بإنشاء مهمة {todo} في القائمة {calendar}",
    "You created to-do {todo} in list {calendar}" : "أنت قمت بإنشاء مهمة {todo} في القائمة {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} قام بحذف مهمة {todo} من القائمة {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "أنت قمت بحذف مهمة {todo} من القائمة {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} قام بتعديل مهمة {todo} في القائمة {calendar}",
    "You updated to-do {todo} in list {calendar}" : "أنت قمت بتعديل مهمة {todo} في القائمة {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} أنجز المهمة {todo} في القائمة{calendar}",
    "You solved to-do {todo} in list {calendar}" : "أنت أنجزت المهمة {todo} في القائمة {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} أعاد فتح المهمة {todo} في القائمة {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "أنت أعدت فتح المهمة {todo} في القائمة {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} قام بنقل المهمة {todo} من القائمة {sourceCalendar} إلى القائمة {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "أنت قمت بنقل المهمة {todo} من القائمة {sourceCalendar} إلى القائمة {targetCalendar}",
    "Calendar, contacts and tasks" : "التقويم، و جهات الاتصال، و قائمة المهام",
    "A <strong>calendar</strong> was modified" : " <strong>تقويم</strong> تمّ تعديله",
    "A calendar <strong>event</strong> was modified" : "<strong>حدث</strong> في تقويم تمّ تعديله",
    "A calendar <strong>to-do</strong> was modified" : " <strong>مهمة</strong> في تقويم تمّ تعديلها",
    "Contact birthdays" : "أعياد ميلاد جهات الاتصال",
    "Death of %s" : "وفاة %s",
    "Untitled calendar" : "تقويم بدون اسم",
    "Calendar:" : "التقويم:",
    "Date:" : "التاريخ:",
    "Where:" : "المكان:",
    "Description:" : "الوصف:",
    "_%n year_::_%n years_" : ["في %n أعوام","في %nعام","في %nأعوام","في %nأعوام","في %n أعوام","في %nأعوام"],
    "_%n month_::_%n months_" : [" %n شهور","%n شهر","%n  شهور","%n  شهور","%n  شهور","%n شهور"],
    "_%n day_::_%n days_" : ["%n أيام","%n يوم","%nأيام","%nأيام","%n أيام","%n أيام"],
    "_%n hour_::_%n hours_" : ["%nساعات","%n ساعة","%n ساعات","%n ساعات","%n ساعات","%n ساعات"],
    "_%n minute_::_%n minutes_" : ["%n دقيقة","%n دقيقة","%n دقيقتيْن","%n دقائق","%n دقائق","%n دقائق"],
    "%s (in %s)" : "%s (في %s)",
    "%s (%s ago)" : "%s (%s مضت)",
    "Calendar: %s" : "التقويم: %s",
    "Date: %s" : "التاريخ: %s",
    "Description: %s" : "الوصف: %s",
    "Where: %s" : "المكان: %s",
    "%1$s via %2$s" : "%1$s عبر %2$s",
    "Cancelled: %1$s" : "مُلغىً: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" تمّ إلغاؤه",
    "Re: %1$s" : "إعادة: %1$s",
    "%1$s has accepted your invitation" : "%1$s قبل دعوتك",
    "%1$s has tentatively accepted your invitation" : "%1$s قبل دعوتك بشكل مبدئي",
    "%1$s has declined your invitation" : "%1$s لم يقبل دعوتك",
    "%1$s has responded to your invitation" : "%1$s استجاب لدعوتك",
    "Invitation updated: %1$s" : "تحديث الدعوة: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s تحديث الحدث \"%2$s\"",
    "Invitation: %1$s" : "دعوة: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s يرغب في دعوتكم إلى \"%2$s\"",
    "Organizer:" : "تنظيم:",
    "Attendees:" : "الحُضُور:",
    "Title:" : "العنوان:",
    "Time:" : "الوقت:",
    "Location:" : "المكان :",
    "Link:" : "الرابط:",
    "Accept" : "قبول",
    "Decline" : "رفض",
    "More options …" : "مزيد مِن الخيارات…",
    "More options at %s" : "خيارات أخرى في %s",
    "Contacts" : "المُراسِلون",
    "{actor} created address book {addressbook}" : "{actor} أنشأ دفتر العناوين {addressbook}",
    "You created address book {addressbook}" : "أنت أنشأت دفتر العناوين {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} قام بحذف دفتر العناوين {addressbook}",
    "You deleted address book {addressbook}" : "أنت قمت بحذف دفتر العناوين {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} قام بتعديل دفتر العناوين {addressbook}",
    "You updated address book {addressbook}" : "أنت قمت بتعديل دفتر العناوين {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} قام بمشاركة دفتر العناوين {addressbook} معك",
    "You shared address book {addressbook} with {user}" : "أنت قمت بمشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} قام بمشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} قام بإلغاء مشاركة دفتر العناوين {addressbook} معك",
    "You unshared address book {addressbook} from {user}" : "أنت قمت بإلغاء مشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} قام بإلغاء مشاركة دفتر العناوين {addressbook} مع {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} قام بإلغاء مشاركته في دفتر العناوين {addressbook} ",
    "You shared address book {addressbook} with group {group}" : "أنت قمت بمشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} قام بمشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "You unshared address book {addressbook} from group {group}" : "أنت قمت بإلغاء مشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} قام بإلغاء مشاركة دفتر العناوين {addressbook} مع المجموعة {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} قام بإنشاء جهة اتصال {card} في دفتر العناوين {addressbook}",
    "You created contact {card} in address book {addressbook}" : "أنت قمت بإنشاء جهة اتصال {card} في دفتر العناوين {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} قام بحذف جهة الاتصال {card} من دفتر العناوين {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "أنت قمت بحذف جهة الاتصال {card} من دفتر العناوين {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} قام بتحديث جهة الاتصال {card} في دفتر العناوين {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "أنت قمت بتحديث جهة الاتصال {card} في دفتر العناوين {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "تمّ تعديل <strong>جهة الاتصال</strong> أو <strong>دفتر العناوين</strong> ",
    "Accounts" : "حسابات",
    "System address book which holds all accounts" : "دفتر عناوين النظام الذي يحوي كل الحسابات",
    "File is not updatable: %1$s" : "ملف غير قابل للتعديل: %1$s",
    "Could not write to final file, canceled by hook" : "تعذرت الكتابة إلى الملف النهائي، تم إلغاؤه بواسطة خطّاف hook",
    "Could not write file contents" : "تعذرت كتابة محتويات الملف",
    "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%n بايت"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "حدث خطأ أثناء نسخ الملف إلى الموقع المقصد (تمّ نسخه: %1$s, حجم الملف المتوقع: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "الحجم المتوقع للملف هو %1$s؛ بينما المقروء من ( الجهاز العميل لنكست كلاود)  و المكتوب في (تخزين نكست كلاود) هو %2$s. يمكن أن يكون السبب إمّا مشكلة اتصال في جانب الجهاز العميل أو مشكلة في الكتابة في وحدة التخزين في جانب خادوم نكست كلاود .",
    "Could not rename part file to final file, canceled by hook" : "تعذّرت إعادة تسمية ملف جزئي إلى ملف نهائي. تمّ الإلغاء من قِبَل الخطّاف hook.",
    "Could not rename part file to final file" : "تعذّرت إعادة تسمية ملف جزئي إلى ملف نهائي",
    "Failed to check file size: %1$s" : "إخفاق في تحديد حجم الملف: %1$s",
    "Could not open file" : "تعذّر فتح الملف",
    "Encryption not ready: %1$s" : "التشفير غير جاهز: %1$s",
    "Failed to open file: %1$s" : "تعذّر فتح الملف: %1$s",
    "Failed to unlink: %1$s" : "تعذّر فك الارتباط: %1$s",
    "Invalid chunk name" : "اسم كتلة chunk غير صحيح",
    "Could not rename part file assembled from chunks" : "تعذّرت إعادة تسمية ملف جزئي مُجمّعٍ من كُتلٍ chunks",
    "Failed to write file contents: %1$s" : "إخفاق في كتابة محتويات الملف: %1$s",
    "File not found: %1$s" : "ملف غير موجود: %1$s",
    "System is in maintenance mode." : "النظام في حالة صيانة.",
    "Upgrade needed" : "الترقية لإصدارٍ أحدث لازمةٌٍ",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "%s الخاص بك يجب تهيئته لاستخدام HTTPS حتى يمكن استعمال CalDAV و CardDAV في نظام التشغيل iOS/macOS. ",
    "Configures a CalDAV account" : "تكوين حساب CalDAV",
    "Configures a CardDAV account" : "تكوين حساب CardDAV",
    "Events" : "أحداث",
    "Untitled task" : "مهمة بدون اسم",
    "Completed on %s" : "تمّ الانتهاء منه في %s",
    "Due on %s by %s" : "مطلوبٌ في %s من قِبَل%s",
    "Due on %s" : "مطلوبٌ في %s",
    "DAV system address book" : "دفتر عناوين نظام DAV",
    "No outstanding DAV system address book sync." : "لا توجد أي مزامنات معلقة لدفتر عناوني نظام DAV.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "لم يتم تشغيل مزامنة دفتر عناوين نظام DAV حتى الآن بسبب أن خادومك يحتوي على أكثر من 1000 مستخدم أو بسبب حدوث خطأ. يرجى تشغيل المزامنة يدويًا عن طريق الأمر السطري:\n\"occ dav:sync-system-addressbook\"",
    "Migrated calendar (%1$s)" : "تقويم مُرحّل (%1$s)",
    "Calendars including events, details and attendees" : "تحوي التقاويم الأحداث، و تفاصيلها، و الحُضُور",
    "Contacts and groups" : "جهات الاتصال والمجموعات",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "النقطة الحدّيّة endpoint لـ WebDAV",
    "First day" : "أوّل يومٍ",
    "Last day (inclusive)" : "آخر يوم (مشمولاً)",
    "Short absence status" : "حالة الغياب القصير",
    "Long absence Message" : "رسالة الغياب الطويل",
    "Save" : "حفظ",
    "Disable absence" : "تعطيل الغياب",
    "Absence saved" : "تمّ حفظ الغياب",
    "Failed to save your absence settings" : "تعذّر حفظ إعداداتك للغياب",
    "Absence cleared" : "تمّ محو الغياب",
    "Failed to clear your absence settings" : "تعذّر محو إعداداتك للغياب",
    "Time zone:" : "منطقة زمنية:",
    "to" : "إلى",
    "Delete slot" : "حذف فُرَضَةٍ slot زمنيّةٍ",
    "No working hours set" : "لم يتم تحديد ساعات العمل",
    "Add slot" : "أضِف فُرَضَةً slot زمنيّةً",
    "Weekdays" : "أيام الأسبوع",
    "Monday" : "الإثنين",
    "Tuesday" : "الثلاثاء",
    "Wednesday" : "الأربعاء",
    "Thursday" : "الخميس",
    "Friday" : "الجمعة",
    "Saturday" : "السبت",
    "Sunday" : "الأحد",
    "Pick a start time for {dayName}" : "إختَر وقت البدء ليوم {dayName}",
    "Pick a end time for {dayName}" : "إختَر وقت الانتهاء ليوم {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "قم بتعيين حالة المستخدم تلقائيًا على \"عدم الإزعاج\" خارج نطاق أوقات التوافر لكتم جميع الإشعارات",
    "Failed to load availability" : "إخفاق في تحميل أوقات التوافر",
    "Saved availability" : "تمّ حفظ أوقات التوافر",
    "Failed to save availability" : "إخفاق في حفظ أوقات التواجد",
    "Availability" : "أوقات التواجد availability",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "إذا قمت بتعيين إعدادات ساعات عملك، فسيعرف الأشخاص الآخرون متى تكون خارج المكتب عندما يرغبونن في حجز موعد للاجتماع بك.",
    "Absence" : "غياب",
    "Configure your next absence period." : "قٌم بتهيئة فترة غيابك القادمة.",
    "Calendar server" : "خادوم التقويم",
    "Send invitations to attendees" : "إرسال دعوات للمُستهدفين بالحُضُُور",
    "Automatically generate a birthday calendar" : "تجاهل تقويم أعياد الميلاد تلقائيّاً",
    "Birthday calendars will be generated by a background job." : "تقويم أعياد الميلاد سيتم توليده من قِبَل مهمةٍ في الخلفية.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "ومن ثمّ لن تكون متاحةً فور التفعيل بل ستظهر بعد مرور بعض الوقت.",
    "Send notifications for events" : "إرسال إشعارات حول الأحداث",
    "Notifications are sent via background jobs, so these must occur often enough." : "يتمّ إرسال الإشعارات من قِبَل مهمّةٍ في الخلفية. لذا سيتكرر عمل هذا المهام حسب الحاجة.",
    "Send reminder notifications to calendar sharees as well" : "أرسل إشعارات للتذكير إلى المشتركين بالتقويم كذلك",
    "Reminders are always sent to organizers and attendees." : "إشعارات التذكير يتم إرسالها دائماً إلى مُنظّم أو مُنظّمي الحدث و المستهدفين بحضوره.",
    "Enable notifications for events via push" : "تمكين الإشعارات حول الأحداث عبر الزّجّ push.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "قم أيضاً بتنصيب {calendarappstoreopen} تطبيق التقويم {linkclose}, أو  {calendardocopen} أوصل جهازك و موبايلك للمُزامنة ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "رجاءُ، تأكّد من الإعداد الصحيح لـ {emailopen} خادوم البريد الالكتروني {linkclose}.",
    "There was an error updating your attendance status." : "حدث خطأ في تحديث حالة حضورك.",
    "Please contact the organizer directly." : "رجاءً، تواصل مع المُنظّم أو المُنظّمين مُباشرةً.",
    "Are you accepting the invitation?" : "هل تقبل الدعوة؟",
    "Tentative" : "مبدئي",
    "Your attendance was updated successfully." : "حضورك تم تحديثه بنجاحٍ",
    "To-dos" : "قائمة المهام",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "إذا قمت بتهيئة ساعات العمل الخاصة بك، فسيظهر للمستخدمين الآخرين عندما يحجزون معك موعداً إذا ما كنت في المكتب أو خارجه."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
